/**
 * 地图Header
 */
type MapHeader = {
    /**
     * 原始地图字符串
     */
    mapHeaderStr: string;
    /**
     * 地图协议版本
     */
    version: number;
    /**
     * 地图id
     */
    id: number;
    /**
     * 地图稳定状态（建图分区完成）
     */
    mapStable: boolean;
    /**
     * 地图宽度
     */
    mapWidth: number;
    /**
     * 地图高度
     */
    mapHeight: number;
    /**
     * 地图原点x坐标
     */
    originX: number;
    /**
     * 地图原点y坐标
     */
    originY: number;
    /**
     * 地图分辨率
     */
    mapResolution: number;
    /**
     * 充电桩x坐标
     */
    chargeX: number;
    /**
     * 充电桩y坐标
     */
    chargeY: number;
    /**
     * 相对充电桩坐标（根据原点偏移）
     */
    chargePositionTransformed: {
        x: number;
        y: number;
    } | null;
    /**
     * 地图数据长度（lz4压缩前）
     */
    dataLengthBeforeCompress: number;
    /**
     * 地图数据长度（lz4压缩后）
     */
    dataLengthAfterCompress: number;
};
/**
 * 房间信息
 */
type RoomDecoded = {
    /**
     * 房间id
     */
    roomId: number;
    /**
     * 房间id+点类型组合的hex (00-ff)
     */
    pointHex: string;
    /**
     * 房间名称
     */
    name: string;
    /**
     * 清扫顺序
     */
    order: number;
    /**
     * 吸力
     */
    suction: number;
    /**
     * 水量
     */
    cistern: number;
    /**
     * 颜色顺序
     */
    colorOrder: number;
    /**
     * 清扫次数
     */
    sweepTimes: number;
    /**
     * 拖地次数
     */
    mopTimes: number;
    /**
     * 是否禁止清扫
     */
    sweepForbidden: boolean;
    /**
     * 是否禁止拖地
     */
    mopForbidden: boolean;
    /**
     * 是否开启y字拖
     */
    yMop: boolean;
};
/**
 * 地图数据
 */
type MapData = {
    /**
     * 房间信息集合
     */
    mapRooms: RoomDecoded[];
    /**
     * 地图点集字符串
     */
    mapPointsStr: string;
};
/**
 * 路径Header
 */
type PathHeader = {
    /**
     * 路径版本
     */
    version: number;
    /**
     * 一次完整清扫的路径图标识
     */
    pathId: number;
    /**
     * 0x00 正常路径数据上报标志位
     * 0x01 初始化路径ID从00开始标志位（路径ID从00开始的前5个包需使用高标志位上报）
     */
    initFlag: number;
    /**
     * 路径类型
     */
    type: number;
    /**
     * 路径点数量
     */
    count: number;
    /**
     * 机器人朝向
     */
    direction: number;
    /**
     * 路径数据长度（lz4压缩后）
     */
    dataLengthAfterCompress: number;
};
/**
 * 路径点类型
 */
type PathPointType = 'common' | 'charge' | 'transitions' | 'mop';
/**
 * 路径点
 */
type PathPoint = {
    /**
     * x坐标
     */
    x: number;
    /**
     * y坐标
     */
    y: number;
    /**
     * 路径点类型
     */
    type: PathPointType;
};
/**
 * 路径数据
 */
type PathData = {
    /**
     * 路径Header
     */
    pathHeader: PathHeader;
    /**
     * 路径点集
     */
    pathPoints: PathPoint[];
};
/**
 * 标准功能数据数组(byte默认为1)
 */
type DataArray = ({
    value: number;
    byte?: number;
} | number | string)[];
/**
 * 坐标点
 */
type Point = {
    x: number;
    y: number;
};
/**
 * 0x00-both_work
 *
 * 0x01-only_sweep
 *
 * 0x02-only_mop
 */
type CleanMode = number;
/**
 * 0x00-closed
 * 0x01-gentle
 * 0x02-normal
 * 0x03-strong
 * 0x04-max
 */
type Suction = number;
/**
 * 0x00-closed
 * 0x01-low
 * 0x02-middle
 * 0x03-high
 */
type Cistern = number;
/**
 * 0x00-off
 * 0x01-open
 * 0x03-high
 */
type yMop = number;
/**
 * 0x00 - 矩形
 *
 * 0x01 - 多边形
 */
type ShapeType = number;
/**
 * 0x00 - 全禁
 *
 * 0x01 - 禁扫
 *
 * 0x02 - 禁拖
 */
type VirtualAreaMode = number;
/**
 * 禁区
 */
type VirtualArea = {
    /**
     * 禁区点集
     */
    points: Point[];
    /**
     * 禁区类型
     */
    mode: VirtualAreaMode;
    /**
     * 禁区名称
     */
    name?: string;
};
/**
 * 定点清扫区域
 */
type Zone = {
    /**
     * 清扫区域点集
     */
    points: Point[];
    /**
     * 清扫区域名称
     */
    name?: string;
    advanced?: {
        id: number;
        localSave: number;
        cleanMode: CleanMode;
        order: number;
        cleanTimes: number;
        suction: Suction;
        cistern: Cistern;
    };
};

/**
 * 解析地图数据
 * @param mapStr 原始地图字符串
 * @returns 地图数据
 */
declare const decodeMap: (mapStr: string) => {
    /**
     * 地图Header
     */
    mapHeader: MapHeader;
    /**
     * 地图数据
     */
    mapData: MapData;
};

/**
 * 解析地图Header
 * @param mapStr 原始地图字符串
 * @returns 地图Header数据
 */
declare const decodeMapHeader: (mapStr: string) => MapHeader;

/**
 * 解析地图数据
 * @param mapStr 原始地图字符串
 * @param mapHeader 地图Header数据
 * @returns 地图点集及房间相关数据
 */
declare const decodeMapData: (mapStr: string, mapHeader: MapHeader) => MapData;

/**
 * 解析路径数据
 * @param pathStr 原始路径字符串
 * @returns 路径数据
 */
declare const decodePath: (pathStr: string) => PathData;

/**
 * 解析路径点集
 * @param pathStr 原始路径字符串
 * @param pathHeader 路径Header数据
 * @returns 路径点集数据
 */
declare const decodePathData: (pathStr: string, pathHeader: PathHeader) => PathPoint[];

/**
 * 解析路径Header
 * @param pathStr 原始路径字符串
 * @returns 路径Header数据
 */
declare const decodePathHeader: (pathStr: string) => PathHeader;

/**
 * *虚拟墙设置0x12/0x13
 *
 * 向设备请求虚拟墙数据(0x13) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestVirtualWallV1: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *虚拟墙设置0x12/0x13
 *
 * 设置虚拟墙的指令(0x12) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeVirtualWallV1: (params: {
    walls: Point[][];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *虚拟墙设置0x12/0x13
 *
 * 从指令中解析获取虚拟墙数据(0x13) | Robot ➜ App
 * @param params 参数
 * @returns 虚拟墙数据
 */
declare const decodeVirtualWallV1: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => Point[][] | null;

/**
 * *虚拟墙设置0x48/0x49
 *
 * 向设备请求虚拟墙数据(0x49) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestVirtualWallV2: (params?: {
    version?: '0' | '1';
}) => string;

/**
 * *选区清扫0x14/0x15
 *
 * 向设备请求选区清扫数据(0x15) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestRoomCleanV1: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *选区清扫0x14/0x15
 *
 * 设置选区清扫的指令(0x14) | App ➜ Robot
 * @param params 参数 - 支持传入roomHexIds或roomIds
 * @returns 指令
 */
declare const encodeRoomCleanV1: (params: {
    cleanTimes: number;
    roomHexIds?: string[];
    roomIds?: number[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * *选区清扫0x14/0x15
 *
 * 从指令中解析获取选区清扫信息(0x15) | Robot ➜ App
 * @param params 参数
 * @returns 选区清扫信息
 */
declare const decodeRoomCleanV1: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => {
    cleanTimes: number;
    roomIds: number[];
    roomHexIds: string[];
};

type Room$2 = {
    roomHexId?: string;
    roomId?: number;
    cleanTimes: number;
    yMop: yMop | 'ff';
    suction: Suction | 'ff';
    cistern: Cistern | 'ff';
};
/**
 * *选区清扫0x56/0x57
 *
 * 向设备请求选区清扫数据(0x57) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestRoomCleanV2: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *选区清扫0x56/0x57
 *
 * 设置选区清扫的指令(0x56) | App ➜ Robot
 * @param params 参数 - 支持传入roomHexIds或roomIds
 * @returns 指令
 */
declare const encodeRoomCleanV2: (params: {
    rooms: Room$2[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * *选区清扫0x56/0x57
 *
 * 从指令中解析获取选区清扫信息(0x57) | Robot ➜ App
 * @param params 参数
 * @returns 选区清扫信息
 */
declare const decodeRoomCleanV2: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => Room$2[] | null;

/**
 * *定点清扫0x16/0x17
 *
 * 向设备请求定点清扫数据(0x17) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestSpotCleanV1: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * * *定点清扫0x16/0x17
 *
 * 设置定点清扫的指令(0x16) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeSpotCleanV1: (params: {
    point: Point;
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *定点清扫0x16/0x17
 *
 * 从指令中解析获取定点清扫数据(0x17) | Robot ➜ App
 * @param params 参数
 * @returns 定点清扫信息
 */
declare const decodeSpotCleanV1: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    point: Point;
} | null;

/**
 * *定点清扫0x3e/0x3f
 *
 * 向设备请求定点清扫数据(0x3f) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestSpotCleanV2: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * * *定点清扫0x3e/0x3f (注意根据Protocol version不同，协议内容有区别)
 *
 * 设置定点清扫的指令(0x3e) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeSpotCleanV2: (params: {
    protocolVersion: 1 | 2;
    points: Point[];
    origin: Point;
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *定点清扫0x3e/0x3f (注意根据Protocol version不同，协议内容有区别)
 *
 * 从指令中解析获取定点清扫数据(0x3f) | Robot ➜ App
 * @param params 参数
 * @returns 定点清扫信息
 */
declare const decodeSpotCleanV2: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: 1 | 2;
    points: Point[];
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
};

/**
 * *禁区设置0x38/0x39
 *
 * 向设备请求禁区数据(0x3f) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestVirtualAreaV2: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * * *禁区设置0x38/0x39 (注意根据Protocol version不同，协议内容有区别)
 *
 * 设置禁区的指令(0x3e) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeVirtualAreaV2: (params: {
    protocolVersion: 1 | 2;
    virtualAreas: VirtualArea[];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *禁区设置0x38/0x39 (注意根据Protocol version不同，协议内容有区别)
 *
 * 从指令中解析获取禁区数据(0x13) | Robot ➜ App
 * @param params 参数
 * @returns 禁区数据
 */
declare const decodeVirtualAreaV2: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: 1 | 2;
    virtualAreas: VirtualArea[];
};

/**
 * *分区分割0x1c/0x1d
 *
 * 向设备下发的分区分割指令(0x1c) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodePartitionDivisionV1: (params: {
    roomId: number;
    points: Point[];
    origin: Point;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *分区分割0x1c/0x1d
 *
 * 解析设备响应的分区分割结果(0x1d) | Robot ➜ App
 * @param params 参数
 * @returns 分区分割结果
 */
declare const decodePartitionDivisionV1: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    ret: number;
    success: boolean;
    roomId: number;
    points: Point[];
};

/**
 * *分区合并0x1e/0x1f
 *
 * 向设备下发的分区合并指令(0x1e) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodePartitionMergeV1: (params: {
    roomIds: number[];
    version?: '0' | '1';
}) => string;
/**
 * *分区合并0x1e/0x1f
 *
 * 解析设备响应的分区合并结果(0x1f) | Robot ➜ App
 * @param params 参数
 * @returns 分区合并结果
 */
declare const decodePartitionMergeV1: (params: {
    command: string;
    version?: '0' | '1';
}) => {
    ret: number;
    success: boolean;
};

type Room$1 = {
    name: string;
    roomHexId?: string;
    roomId?: number;
};
/**
 * *设置房间名称0x24/0x25
 *
 * 向设备下发的设置房间名称指令(0x24) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeSetRoomNameV1: (params: {
    rooms: Room$1[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * *设置房间名称0x24/0x25
 *
 * 解析设备响应的设置房间名称结果(0x25) | Robot ➜ App
 * @param params 参数
 * @returns 设置房间名称结果
 */
declare const decodeSetRoomNameV1: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => Room$1[] | null;

type Room = {
    roomHexId?: string;
    roomId?: number;
    cleanTimes: number;
    yMop: yMop | 'ff';
    suction: Suction | 'ff';
    cistern: Cistern | 'ff';
};
/**
 * *设置房间属性0x22/0x23
 *
 * 向设备下发的设置房间属性指令(0x23) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeSetRoomPropertyV1: (params: {
    rooms: Room[];
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => string;
/**
 * *设置房间属性0x24/0x25
 *
 * 解析设备响应的设置房间属性结果(0x25) | Robot ➜ App
 * @param params 参数
 * @returns 设置房间属性结果
 */
declare const decodeSetRoomPropertyV1: (params: {
    command: string;
    mapVersion?: 0 | 1 | 2;
    version?: '0' | '1';
}) => Room[] | null;

/**
 * *划区清扫0x3a/0x3b
 *
 * 向设备请求划区清扫数据(0x3b) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const requestZoneCleanV2: (params?: {
    version?: '0' | '1';
}) => string;
/**
 * *划区清扫0x3a/0x3b (注意根据Protocol version不同，协议内容有区别)
 *
 * 划区清扫的指令(0x3a) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeZoneCleanV2: (params: {
    protocolVersion: 1 | 2 | 3;
    zones: Zone[];
    origin: Point;
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
    mapScale?: number;
    version?: '0' | '1';
}) => string;
/**
 * *划区清扫0x3a/0x3b (注意根据Protocol version不同，协议内容有区别)
 *
 * 从指令中解析获取划区清扫数据(0x3b) | Robot ➜ App
 * @param params 参数
 * @returns 划区清扫数据
 */
declare const decodeZoneCleanV2: (params: {
    command: string;
    mapScale?: number;
    version?: '0' | '1';
}) => {
    protocolVersion: 1 | 2 | 3;
    zones: Zone[];
    cleanMode?: CleanMode;
    suction?: Suction;
    cistern?: Cistern;
    cleanTimes?: number;
};

/**
 * *勿扰时间设置0x40/0x41
 *
 * 设置勿扰时间的指令(0x14) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeDoNotDisturbV2: (params: {
    enable: boolean;
    startHour: number;
    startMinute: number;
    endHour: number;
    endMinute: number;
    timeZone?: number;
    version?: '0' | '1';
}) => string;
/**
 * *勿扰时间设置0x40/0x41
 *
 * 从指令中解析获取勿扰时间数据(0x15) | Robot ➜ App
 * @param params 参数
 * @returns 勿扰时间数据
 */
declare const decodeDoNotDisturbV2: (params: {
    command: string;
    version?: '0' | '1';
}) => {
    enable: boolean;
    timeZone: number;
    startHour: number;
    startMinute: number;
    endHour: number;
    endMinute: number;
};

/**
 * *重置当前首页地图0x42/0x43
 *
 * 向设备下发的快速建图指令(0x42) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeResetMapV1: (params?: {
    version?: '0' | '1';
}) => string;

/**
 * *快速建图0x3c/0x3d
 *
 * 向设备下发的快速建图指令(0x3c) | App ➜ Robot
 * @param params 参数
 * @returns 指令
 */
declare const encodeQuickMapV1: (params?: {
    version?: '0' | '1';
}) => string;

declare const MAP_HEADER_LENGTH = 24;
declare const ROOM_PROPERTY_LENGTH = 26;
declare const ROOM_NAME_LENGTH = 20;
declare const ROOM_VERTICES_NUM_LENGTH = 1;

declare const PATH_HEADER_LENGTH = 13;
declare const PATH_POINT_TYPE_MAP: Record<string, PathPointType>;

/**
 * 标准功能帧头
 */
declare const STANDARD_FEATURE_HEADER = "aa";
/**
 * 虚拟墙设置V1 App ➜ Robot
 */
declare const VIRTUAL_WALL_CMD_APP_V1 = "12";
/**
 * 虚拟墙设置V1 Robot ➜ App
 */
declare const VIRTUAL_WALL_CMD_ROBOT_V1 = "13";
/**
 * 虚拟墙设置V2 App ➜ Robot
 */
declare const VIRTUAL_WALL_CMD_APP_V2 = "48";
/**
 * 虚拟墙设置V2 Robot ➜ App
 */
declare const VIRTUAL_WALL_CMD_ROBOT_V2 = "49";
/**
 * 虚拟墙设置V2 App ➜ Robot
 */
declare const VIRTUAL_AREA_CMD_APP_V2 = "38";
/**
 * 虚拟墙设置V2 Robot ➜ App
 */
declare const VIRTUAL_AREA_CMD_ROBOT_V2 = "39";
/**
 * 选区清扫V1 App ➜ Robot
 */
declare const ROOM_CLEAN_CMD_APP_V1 = "14";
/**
 * 选区清扫V1 Robot ➜ App
 */
declare const ROOM_CLEAN_CMD_ROBOT_V1 = "15";
/**
 * 选区清扫V2 App ➜ Robot
 */
declare const ROOM_CLEAN_CMD_APP_V2 = "56";
/**
 * 选区清扫V2 Robot ➜ App
 */
declare const ROOM_CLEAN_CMD_ROBOT_V2 = "57";
/**
 * 定点清扫V1 App ➜ Robot
 */
declare const SPOT_CLEAN_CMD_APP_V1 = "16";
/**
 * 定点清扫V1 Robot ➜ App
 */
declare const SPOT_CLEAN_CMD_ROBOT_V1 = "17";
/**
 * 定点清扫V2 App ➜ Robot
 */
declare const SPOT_CLEAN_CMD_APP_V2 = "3e";
/**
 * 定点清扫V2 Robot ➜ App
 */
declare const SPOT_CLEAN_CMD_ROBOT_V2 = "3f";
/**
 * 分区分割V1 App ➜ Robot
 */
declare const PARTITION_DIVISION_CMD_APP_V1 = "1c";
/**
 * 分区分割V1 Robot ➜ App
 */
declare const PARTITION_DIVISION_CMD_ROBOT_V1 = "1d";
/**
 * 分区合并V1 App ➜ Robot
 */
declare const PARTITION_MERGE_CMD_APP_V1 = "1e";
/**
 * 分区合并V1 Robot ➜ App
 */
declare const PARTITION_MERGE_CMD_ROBOT_V1 = "1f";
/**
 * 设置房间属性V1 App ➜ Robot
 */
declare const SET_ROOM_PROPERTY_CMD_APP_V1 = "22";
/**
 * 设置房间属性V1 Robot ➜ App
 */
declare const SET_ROOM_PROPERTY_CMD_ROBOT_V1 = "23";
/**
 * 设置房间名称V1 App ➜ Robot
 */
declare const SET_ROOM_NAME_CMD_APP_V1 = "24";
/**
 * 设置房间名称V1 Robot ➜ App
 */
declare const SET_ROOM_NAME_CMD_ROBOT_V1 = "25";
/**
 * 划区清扫V1 App ➜ Robot
 */
declare const ZONE_CLEAN_CMD_APP_V1 = "28";
/**
 * 划区清扫V1 Robot ➜ App
 */
declare const ZONE_CLEAN_CMD_ROBOT_V1 = "29";
/**
 * 划区清扫V2 App ➜ Robot
 */
declare const ZONE_CLEAN_CMD_APP_V2 = "3a";
/**
 * 划区清扫V2 Robot ➜ App
 */
declare const ZONE_CLEAN_CMD_ROBOT_V2 = "3b";
/**
 * 勿扰时间设置V2 App ➜ Robot
 */
declare const DO_NOT_DISTURB_CMD_APP_V2 = "40";
/**
 * 勿扰时间设置V2 Robot ➜ App
 */
declare const DO_NOT_DISTURB_ROBOT_V2 = "41";
/**
 * 快速建图 App ➜ Robot
 */
declare const QUICK_MAP_CMD_APP_V1 = "3c";
/**
 * 快速建图 Robot ➜ App
 */
declare const QUICK_MAP_CMD_ROBOT_V1 = "3d";
/**
 * 重置地图 App ➜ Robot
 */
declare const RESET_MAP_CMD_APP_V1 = "42";
/**
 * 重置地图 Robot ➜ App
 */
declare const RESET_MAP_CMD_ROBOT_V1 = "43";

/**
 * 构建扫地机标准功能指令 App ➜ Robot
 * @param version 协议版本
 * @param cmd 命令字
 * @param data 数据
 * @returns 指令
 */
declare const encodeStandardFeatureCommand: (cmd: string, data: string, version: '0' | '1') => string;
/**
 * 从指令中解析得到必要信息
 * @param command 指令
 * @param cmd 命令字
 * @param version 协议版本
 * @returns 解析数据
 */
declare const decodeStandardFeatureCommand: (command: string, cmd: string, version?: '0' | '1') => {
    valid: boolean;
    dataLength?: number;
    cmdStr?: string;
    dataStr?: string;
};
/**
 * 从指令中获取命令字
 * @param command 指令
 * @param version 协议版本
 * @returns 命令字
 */
declare const getCmdStrFromStandardFeatureCommand: (command: string, version?: '0' | '1') => string;
/**
 * 将数据数组转化为数据指令
 *
 * 数组项接受
 *
 * 1. 对象类型(可配置不同字节)
 *
 * 2. 数值类型(1个字节的数据可以这么使用)
 *
 * 3. 字符串类型(直接传入byte字符串)
 * @param dataArray 数据数组
 * @returns 数据指令
 */
declare const convertDataArrayToDataStr: (dataArray: DataArray) => string;

export { type Cistern, type CleanMode, DO_NOT_DISTURB_CMD_APP_V2, DO_NOT_DISTURB_ROBOT_V2, type DataArray, MAP_HEADER_LENGTH, type MapData, type MapHeader, PARTITION_DIVISION_CMD_APP_V1, PARTITION_DIVISION_CMD_ROBOT_V1, PARTITION_MERGE_CMD_APP_V1, PARTITION_MERGE_CMD_ROBOT_V1, PATH_HEADER_LENGTH, PATH_POINT_TYPE_MAP, type PathData, type PathHeader, type PathPoint, type PathPointType, type Point, QUICK_MAP_CMD_APP_V1, QUICK_MAP_CMD_ROBOT_V1, RESET_MAP_CMD_APP_V1, RESET_MAP_CMD_ROBOT_V1, ROOM_CLEAN_CMD_APP_V1, ROOM_CLEAN_CMD_APP_V2, ROOM_CLEAN_CMD_ROBOT_V1, ROOM_CLEAN_CMD_ROBOT_V2, ROOM_NAME_LENGTH, ROOM_PROPERTY_LENGTH, ROOM_VERTICES_NUM_LENGTH, type RoomDecoded, SET_ROOM_NAME_CMD_APP_V1, SET_ROOM_NAME_CMD_ROBOT_V1, SET_ROOM_PROPERTY_CMD_APP_V1, SET_ROOM_PROPERTY_CMD_ROBOT_V1, SPOT_CLEAN_CMD_APP_V1, SPOT_CLEAN_CMD_APP_V2, SPOT_CLEAN_CMD_ROBOT_V1, SPOT_CLEAN_CMD_ROBOT_V2, STANDARD_FEATURE_HEADER, type ShapeType, type Suction, VIRTUAL_AREA_CMD_APP_V2, VIRTUAL_AREA_CMD_ROBOT_V2, VIRTUAL_WALL_CMD_APP_V1, VIRTUAL_WALL_CMD_APP_V2, VIRTUAL_WALL_CMD_ROBOT_V1, VIRTUAL_WALL_CMD_ROBOT_V2, type VirtualArea, type VirtualAreaMode, ZONE_CLEAN_CMD_APP_V1, ZONE_CLEAN_CMD_APP_V2, ZONE_CLEAN_CMD_ROBOT_V1, ZONE_CLEAN_CMD_ROBOT_V2, type Zone, convertDataArrayToDataStr, decodeDoNotDisturbV2, decodeMap, decodeMapData, decodeMapHeader, decodePartitionDivisionV1, decodePartitionMergeV1, decodePath, decodePathData, decodePathHeader, decodeRoomCleanV1, decodeRoomCleanV2, decodeSetRoomNameV1, decodeSetRoomPropertyV1, decodeSpotCleanV1, decodeSpotCleanV2, decodeStandardFeatureCommand, decodeVirtualAreaV2, decodeVirtualWallV1, decodeZoneCleanV2, encodeDoNotDisturbV2, encodePartitionDivisionV1, encodePartitionMergeV1, encodeQuickMapV1, encodeResetMapV1, encodeRoomCleanV1, encodeRoomCleanV2, encodeSetRoomNameV1, encodeSetRoomPropertyV1, encodeSpotCleanV1, encodeSpotCleanV2, encodeStandardFeatureCommand, encodeVirtualAreaV2, encodeVirtualWallV1, encodeZoneCleanV2, getCmdStrFromStandardFeatureCommand, requestRoomCleanV1, requestRoomCleanV2, requestSpotCleanV1, requestSpotCleanV2, requestVirtualAreaV2, requestVirtualWallV1, requestVirtualWallV2, requestZoneCleanV2, type yMop };
